@@ -24,7 +24,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "1.3.1"
+__version__ = "1.3.2"
 
 
 def _autotype(var):
@@ -46,6 +46,14 @@ def _autostr(var, precision=8):
     return str(var)
 
 
+class ParseError(Exception):
+    "Exception object to be raised when a spectrum file/string is malformed"
+    def __init__(self, errmsg):
+        self.msg = errmsg
+    def __repr__(self):
+        return self.msg
+
+
 
 class Block(object):
     """
@@ -233,7 +241,7 @@ def readSLHA(spcstr, ignorenobr=False):
             if decays.has_key(pid):
                 decays[pid].mass = blocks["MASS"].entries[pid]
     except:
-        raise Exception("No MASS block found, from which to populate particle masses")
+        raise ParseError("No MASS block found: cannot populate particle masses")
 
     return blocks, decays
 
